#' `auk`: eBird Data Extraction and Processing in R
#'
#' Tools for extracting and processing eBird data from the eBird Basic Dataset 
#' (EBD).
#'
#' @keywords internal
"_PACKAGE"

## usethis namespace: start
#' @importFrom rlang .data
#' @importFrom stringr str_interp
## usethis namespace: end
NULL
